@@ -187,9 +187,17 @@ To format statistics reports::
 
 """
 
+import logging
+import os
+import sys
+import threading
+import time
+
+import cherrypy
+from cherrypy._cpcompat import json
+
 # ------------------------------- Statistics -------------------------------- #
 
-import logging
 if not hasattr(logging, 'statistics'):
     logging.statistics = {}
 
@@ -210,12 +218,6 @@ def extrapolate_statistics(scope):
 
 # -------------------- CherryPy Applications Statistics --------------------- #
 
-import sys
-import threading
-import time
-
-import cherrypy
-
 appstats = logging.statistics.setdefault('CherryPy Applications', {})
 appstats.update({
     'Enabled': True,
@@ -390,24 +392,13 @@ class StatsTool(cherrypy.Tool):
                 sq.pop(0)
 
 
-import cherrypy
 cherrypy.tools.cpstats = StatsTool()
 
 
 # ---------------------- CherryPy Statistics Reporting ---------------------- #
 
-import os
 thisdir = os.path.abspath(os.path.dirname(__file__))
 
-try:
-    import json
-except ImportError:
-    try:
-        import simplejson as json
-    except ImportError:
-        json = None
-
-
 missing = object()
 
 locale_date = lambda v: time.strftime('%c', time.gmtime(v))
@@ -475,6 +466,7 @@ class StatsPage(object):
         },
     }
 
+    @cherrypy.expose
     def index(self):
         # Transform the raw data into pretty output for HTML
         yield """
@@ -578,7 +570,6 @@ table.stats2 th {
 </body>
 </html>
 """
-    index.exposed = True
 
     def get_namespaces(self):
         """Yield (title, scalars, collections) for each namespace."""
@@ -678,22 +669,22 @@ table.stats2 th {
         return headers, subrows
 
     if json is not None:
+        @cherrypy.expose
         def data(self):
             s = extrapolate_statistics(logging.statistics)
             cherrypy.response.headers['Content-Type'] = 'application/json'
             return json.dumps(s, sort_keys=True, indent=4)
-        data.exposed = True
 
+    @cherrypy.expose
     def pause(self, namespace):
         logging.statistics.get(namespace, {})['Enabled'] = False
         raise cherrypy.HTTPRedirect('./')
-    pause.exposed = True
     pause.cp_config = {'tools.allow.on': True,
                        'tools.allow.methods': ['POST']}
 
+    @cherrypy.expose
     def resume(self, namespace):
         logging.statistics.get(namespace, {})['Enabled'] = True
         raise cherrypy.HTTPRedirect('./')
-    resume.exposed = True
     resume.cp_config = {'tools.allow.on': True,
                         'tools.allow.methods': ['POST']}
